Installation
============

The simplest way to install is downloading from PyPI::

    $ pip install -U iptvtools

If you prefer the latest master branch or want to make some code changes, you can download and install with the following command::

    $ git clone https://github.com/huxuan/iptvtools.git
    $ cd iptvtools
    $ pip install .
